![PLATEypusLogo](https://user-images.githubusercontent.com/49458891/116960335-185c1500-ac6e-11eb-92e0-369334eb7882.png)

A GUI to process and plot high throughput bulk cytokine, surface marker, and single cell data exported from flowjo  
  
Main powerpoint tutorial for GUI is hosted on google drive:   
https://drive.google.com/file/d/1jt8ZlOiArbiVK-RyF1_rrS8swEYsqWae/view?usp=sharing

To use this package:
1. If anaconda is not installed, follow installation instructions here: https://docs.anaconda.com/anaconda/install/
2. Start terminal, type in and enter:
```
conda activate
```
3. Now install plateypus via PyPi by typing the following line in the terminal:
```
pip install plateypus
```
4. In this anaconda environment, type: 
```
python3 -m plateypus
```
to start the GUI
